@@ -6,20 +6,23 @@ use std::thread;
 use std::time::Duration;
 
 fn main() -> Result<()> {
-    let command = Command::new("git").arg("--version").exec()?;
-    println!("{:#?}", command);
-
     let c2 = Command::new("git")
         .arg("log")
         .arg("-1")
         .current_dir(&std::env::current_dir().unwrap())
         .exec()?;
-    println!("{:#?}", c2);
+    println!("command display: {}", c2);
+    println!("\ncommand debug:\n{:#?}", c2);
+    println!("\ncommand json compact: {}", serde_json::to_string(&c2)?);
 
-    let c3 = Command::new("ftp").timeout(Duration::new(0, 0)).exec()?;
+    let c3 = Command::new("git")
+        .arg("ls-remote")
+        .arg("https://gitlab.com/crates-rs/reef.git")
+        .arg("HEAD")
+        .timeout(Duration::new(0, 0))
+        .exec()?;
     println!("{:#?}", c3);
 
-    // rake
     let rake_dir = std::env::temp_dir().join("reef.command.rake");
     if !rake_dir.exists() {
         std::fs::create_dir_all(&rake_dir)?;
@@ -36,5 +39,9 @@ fn main() -> Result<()> {
     println!("{:#?}", rake);
     std::fs::remove_file(&rakefile)?;
     std::fs::remove_dir_all(&rake_dir)?;
+
+    // collect recent history
+    let recent = Command::collect("", 3)?;
+    println!("recent:\n{:#?}", recent);
     Ok(())
 }
